==> php55-owncloud-8.2.2.tgz: share/owncloud/apps/files_external/l10n/el.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Η λήψη των τεκμηρίων αιτήματος απέτυχε. Βεβαιώστε ότι το κλειδί εφαρμογής και το μυστικό είναι ορθά.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Η λήψη των τεκμηρίων πρόσβασης απέτυχε. Βεβαιώστε ότι το κλειδί εφαρμογής και το μυστικό είναι ορθά.",
    "Please provide a valid app key and secret." : "Παρακαλούμε δώστε έγκυρο κλειδί εφαρμογής και μυστικό.",
    "Step 1 failed. Exception: %s" : "Το βήμα 1 απέτυχε. Εξαίρεση: %s",
    "Step 2 failed. Exception: %s" : "Το βήμα 2 απέτυχε. Εξαίρεση: %s",
    "External storage" : "Εξωτερική αποθήκευση",
    "Storage with id \"%i\" not found" : "Αποθήκευση με id \"%i\" δεν βρέθηκε",
    "Invalid backend or authentication mechanism class" : "Μη έγκυρη κλάση συστήματος ή μηχανισμού πιστοποίησης",
    "Invalid mount point" : "Μη έγκυρο σημείο ανάρτησης",
    "Objectstore forbidden" : "Απαγορευμένο objectstore",
    "Invalid storage backend \"%s\"" : "Μή έγκυρο σύστημα υποστήριξης αποθήκευσης  \"%s\"",
    "Not permitted to use backend \"%s\"" : "Μη επιτρεπόμενο σύστημα υποστήριξης \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Μη επιτρεπόμενος μηχανισμός πιστοποίησης \"%s\"",
    "Unsatisfied backend parameters" : "Ελλιπείς παράμετροι συστήματος",
    "Unsatisfied authentication mechanism parameters" : "Ελλιπείς παράμετροι μηχανισμού πιστοποίησης",
    "Personal" : "Προσωπικά",
    "System" : "Σύστημα",
    "Grant access" : "Παροχή πρόσβασης",
    "Access granted" : "Πρόσβαση παρασχέθηκε",
    "Error configuring OAuth1" : "Σφάλμα ρύθμισης του OAuth1",
    "Error configuring OAuth2" : "Σφάλμα ρύθμισης του OAuth2",
    "Generate keys" : "Δημιουργία κλειδιών",
    "Error generating key pair" : "Σφάλμα κατά τη δημιουργία ζεύγους κλειδιών",
    "Enable encryption" : "Ενεργοποίηση κρυπτογράφησης",
    "Enable previews" : "Ενεργοποίηση προεπισκοπήσεων",
    "Check for changes" : "Έλεγχος για αλλαγές",
    "Never" : "Ποτέ",
    "Once every direct access" : "Σε κάθε απευθείας πρόσβαση",
    "Every time the filesystem is used" : "Κάθε φορά που χρησιμοποιείται το σύστημα αρχείων",
    "All users. Type to select user or group." : "Όλοι οι χρήστες. Πληκτρολογήστε για να επιλέξετε χρήστη ή ομάδα.",
    "(group)" : "(ομάδα)",
    "Saved" : "Αποθηκεύτηκαν",
    "Access key" : "Κλειδί πρόσβασης",
    "Secret key" : "Μυστικό κλειδί",
    "Builtin" : "Builtin",
    "None" : "Τίποτα",
    "OAuth1" : "OAuth1",
    "App key" : "Κλειδί εφαρμογής",
    "App secret" : "Μυστικό εφαρμογής",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID πελάτη",
    "Client secret" : "Μυστικό πελάτη",
    "OpenStack" : "OpenStack",
    "Username" : "Όνομα χρήστη",
    "Password" : "Κωδικός πρόσβασης",
    "Tenant name" : "Όνομα \"ένοικου\"",
    "Identity endpoint URL" : "URL τελικού σημείου ταυτοποίησης",
    "Rackspace" : "Rackspace",
    "API key" : "Κλειδί Google API",
    "Username and password" : "Όνομα χρήστη και κωδικός πρόσβασης",
    "Session credentials" : "Διαπιστευτήρια συνεδρίας",
    "RSA public key" : "Δημόσιο κλειδί RSA",
    "Public key" : "Δημόσιο κλειδί",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Κάδος",
    "Hostname" : "Όνομα Υπολογιστή",
    "Port" : "Θύρα",
    "Region" : "Περιοχή",
    "Enable SSL" : "Ενεργοποίηση SSL",
    "Enable Path Style" : "Ενεργοποίηση μορφής διαδρομής",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Απομακρυσμένος υποφάκελος",
    "Secure https://" : "Ασφαλής σύνδεση https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Διακομιστής",
    "Secure ftps://" : "Ασφαλής ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Τοπικός",
    "Location" : "Τοποθεσία",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP με σύνδεση με κρυφό κλειδί",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Διαμοιράστε",
    "Domain" : "Τομέας",
    "SMB / CIFS using OC login" : "SMB / CIFS χρησιμοποιώντας λογαριασμό OC",
    "Username as share" : "Όνομα χρήστη ως διαμοιραζόμενος φάκελος",
    "OpenStack Object Storage" : "Αποθήκη αντικειμένων OpenStack",
    "Service name" : "Όνομα υπηρεσίας",
    "Request timeout (seconds)" : "Χρονικό όριο αιτήματος (δευτερόλεπτα)",
    "<b>Note:</b> " : "<b>Σημείωση:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Σημείωση:</b> Η υποστήριξη cURL στην PHP δεν είναι ενεργοποιημένη ή εγκατεστημένη. Η προσάρτηση του %s δεν είναι δυνατή. Παρακαλώ ζητήστε από τον διαχειριστή συστημάτων σας να την εγκαταστήσει.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Σημείωση:</b> Η υποστήριξη FTP στην PHP δεν είναι ενεργοποιημένη ή εγκατεστημένη. Δεν είναι δυνατή η προσάρτηση του %s. Παρακαλώ ζητήστε από τον διαχειριστή συστημάτων σας να την εγκαταστήσει.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Σημείωση:</b> Η επέκταση \"%s\" δεν είναι εγκατεστημένη. Δεν είναι δυνατή η προσάρτηση %s. Παρακαλώ ζητήστε από τον διαχειριστή συστημάτων σας να την εγκαταστήσει.",
    "No external storage configured" : "Δεν έχει ρυθμιστεί κανένα εξωτερικό μέσο αποθήκευσης",
    "You can add external storages in the personal settings" : "Μπορείτε να προσθέσετε εξωτερικά μέσα αποθήκευσης στις προσωπικές ρυθμίσεις",
    "Name" : "Όνομα",
    "Storage type" : "Τύπος αποθηκευτικού χώρου",
    "Scope" : "Εύρος",
    "External Storage" : "Εξωτερικό Αποθηκευτικό Μέσο",
    "Folder name" : "Όνομα φακέλου",
    "Authentication" : "Πιστοποίηση",
    "Configuration" : "Ρυθμίσεις",
    "Available for" : "Διαθέσιμο για",
    "Advanced settings" : "Ρυθμίσεις για προχωρημένους",
    "Delete" : "Διαγραφή",
    "Add storage" : "Προσθηκη αποθηκευσης",
    "Enable User External Storage" : "Ενεργοποίηση Εξωτερικού Αποθηκευτικού Χώρου Χρήστη",
    "Allow users to mount the following external storage" : "Χορήγηση άδειας στους χρήστες να συνδέσουν τα παρακάτω εξωτερικά μέσα αποθήκευσης"
},
"nplurals=2; plural=(n != 1);");

==> php55-owncloud-9.0.0.tgz: share/owncloud/apps/files_external/l10n/el.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Η λήψη των τεκμηρίων αιτήματος απέτυχε. Βεβαιώστε ότι το κλειδί εφαρμογής και το μυστικό είναι ορθά.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Η λήψη των τεκμηρίων πρόσβασης απέτυχε. Βεβαιώστε ότι το κλειδί εφαρμογής και το μυστικό είναι ορθά.",
    "Please provide a valid app key and secret." : "Παρακαλούμε δώστε έγκυρο κλειδί εφαρμογής και μυστικό.",
    "Step 1 failed. Exception: %s" : "Το βήμα 1 απέτυχε. Εξαίρεση: %s",
    "Step 2 failed. Exception: %s" : "Το βήμα 2 απέτυχε. Εξαίρεση: %s",
    "External storage" : "Εξωτερική αποθήκευση",
    "Storage with id \"%i\" not found" : "Αποθήκευση με id \"%i\" δεν βρέθηκε",
    "Invalid backend or authentication mechanism class" : "Μη έγκυρη κλάση συστήματος ή μηχανισμού πιστοποίησης",
    "Invalid mount point" : "Μη έγκυρο σημείο ανάρτησης",
    "Objectstore forbidden" : "Απαγορευμένο objectstore",
    "Invalid storage backend \"%s\"" : "Μή έγκυρο σύστημα υποστήριξης αποθήκευσης  \"%s\"",
    "Not permitted to use backend \"%s\"" : "Μη επιτρεπόμενο σύστημα υποστήριξης \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Μη επιτρεπόμενος μηχανισμός πιστοποίησης \"%s\"",
    "Unsatisfied backend parameters" : "Ελλιπείς παράμετροι συστήματος",
    "Unsatisfied authentication mechanism parameters" : "Ελλιπείς παράμετροι μηχανισμού πιστοποίησης",
    "Insufficient data: %s" : "Μη επαρκή δεδομένα: %s",
    "%s" : "%s",
    "Personal" : "Προσωπικά",
    "System" : "Σύστημα",
    "Grant access" : "Παροχή πρόσβασης",
    "Access granted" : "Πρόσβαση παρασχέθηκε",
    "Error configuring OAuth1" : "Σφάλμα ρύθμισης του OAuth1",
    "Error configuring OAuth2" : "Σφάλμα ρύθμισης του OAuth2",
    "Generate keys" : "Δημιουργία κλειδιών",
    "Error generating key pair" : "Σφάλμα κατά τη δημιουργία ζεύγους κλειδιών",
    "Enable encryption" : "Ενεργοποίηση κρυπτογράφησης",
    "Enable previews" : "Ενεργοποίηση προεπισκοπήσεων",
    "Check for changes" : "Έλεγχος για αλλαγές",
    "Never" : "Ποτέ",
    "Once every direct access" : "Σε κάθε απευθείας πρόσβαση",
    "All users. Type to select user or group." : "Όλοι οι χρήστες. Πληκτρολογήστε για να επιλέξετε χρήστη ή ομάδα.",
    "(group)" : "(ομάδα)",
    "Saved" : "Αποθηκεύτηκαν",
    "Username" : "Όνομα χρήστη",
    "Password" : "Κωδικός πρόσβασης",
    "Save" : "Αποθήκευση",
    "Access key" : "Κλειδί πρόσβασης",
    "Secret key" : "Μυστικό κλειδί",
    "Builtin" : "Builtin",
    "None" : "Τίποτα",
    "OAuth1" : "OAuth1",
    "App key" : "Κλειδί εφαρμογής",
    "App secret" : "Μυστικό εφαρμογής",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID πελάτη",
    "Client secret" : "Μυστικό πελάτη",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Όνομα \"ένοικου\"",
    "Identity endpoint URL" : "URL τελικού σημείου ταυτοποίησης",
    "Rackspace" : "Rackspace",
    "API key" : "Κλειδί Google API",
    "Username and password" : "Όνομα χρήστη και κωδικός πρόσβασης",
    "RSA public key" : "Δημόσιο κλειδί RSA",
    "Public key" : "Δημόσιο κλειδί",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Κάδος",
    "Hostname" : "Όνομα Υπολογιστή",
    "Port" : "Θύρα",
    "Region" : "Περιοχή",
    "Enable SSL" : "Ενεργοποίηση SSL",
    "Enable Path Style" : "Ενεργοποίηση μορφής διαδρομής",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Απομακρυσμένος υποφάκελος",
    "Secure https://" : "Ασφαλής σύνδεση https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Διακομιστής",
    "Secure ftps://" : "Ασφαλής ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Τοπικός",
    "Location" : "Τοποθεσία",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP με σύνδεση με κρυφό κλειδί",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Διαμοιράστε",
    "Domain" : "Τομέας",
    "SMB / CIFS using OC login" : "SMB / CIFS χρησιμοποιώντας λογαριασμό OC",
    "Username as share" : "Όνομα χρήστη ως διαμοιραζόμενος φάκελος",
    "OpenStack Object Storage" : "Αποθήκη αντικειμένων OpenStack",
    "Service name" : "Όνομα υπηρεσίας",
    "Request timeout (seconds)" : "Χρονικό όριο αιτήματος (δευτερόλεπτα)",
    "<b>Note:</b> " : "<b>Σημείωση:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Σημείωση:</b> Η υποστήριξη cURL στην PHP δεν είναι ενεργοποιημένη ή εγκατεστημένη. Η προσάρτηση του %s δεν είναι δυνατή. Παρακαλώ ζητήστε από τον διαχειριστή συστημάτων σας να την εγκαταστήσει.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Σημείωση:</b> Η υποστήριξη FTP στην PHP δεν είναι ενεργοποιημένη ή εγκατεστημένη. Δεν είναι δυνατή η προσάρτηση του %s. Παρακαλώ ζητήστε από τον διαχειριστή συστημάτων σας να την εγκαταστήσει.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Σημείωση:</b> Η επέκταση \"%s\" δεν είναι εγκατεστημένη. Δεν είναι δυνατή η προσάρτηση %s. Παρακαλώ ζητήστε από τον διαχειριστή συστημάτων σας να την εγκαταστήσει.",
    "No external storage configured" : "Δεν έχει ρυθμιστεί κανένα εξωτερικό μέσο αποθήκευσης",
    "You can add external storages in the personal settings" : "Μπορείτε να προσθέσετε εξωτερικά μέσα αποθήκευσης στις προσωπικές ρυθμίσεις",
    "Name" : "Όνομα",
    "Storage type" : "Τύπος αποθηκευτικού χώρου",
    "Scope" : "Εύρος",
    "External Storage" : "Εξωτερικό Αποθηκευτικό Μέσο",
    "Folder name" : "Όνομα φακέλου",
    "Authentication" : "Πιστοποίηση",
    "Configuration" : "Ρυθμίσεις",
    "Available for" : "Διαθέσιμο για",
    "Add storage" : "Προσθηκη αποθηκευσης",
    "Advanced settings" : "Ρυθμίσεις για προχωρημένους",
    "Delete" : "Διαγραφή",
    "Allow users to mount external storage" : "Να επιτρέπεται στους χρήστες η σύνδεση εξωτερικού χώρου",
    "Allow users to mount the following external storage" : "Χορήγηση άδειας στους χρήστες να συνδέσουν τα παρακάτω εξωτερικά μέσα αποθήκευσης"
},
"nplurals=2; plural=(n != 1);");
